pub struct QqLine {
pub slope: f64,
pub intercept: f64,
}Expand description
The fitted reference line of a probability plot, y = slope * x + intercept,
where x are the theoretical quantiles and y the sample quantiles.
Fields
slope: f64Slope of the reference line.
intercept: f64Intercept of the reference line.